# swandashboard

A simple Python package to open Shivdutt Choubey's website.

## Installation

```bash
pip install swandashboard
```

## Usage

```python
from swandashboard import website

website()  # Opens https://swandashboard.github.io in your default browser
```

## License
MIT